==> nextcloud-28.0.7.tar.bz2: nextcloud/apps/activity/l10n/sc.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Flussu de atividade personale de su %s",
    "Your feed URL is invalid" : "S'URL de flussu tuo no est vàlidu",
    "Activity feed" : "Flussu de atividade",
    "Your settings have been updated." : "Cunfiguratzione atualizada.",
    "Settings have been updated." : "Cunfiguratzione atualizada.",
    "Recent activity" : "Atividade reghente",
    "No activities" : "Peruna atividade",
    "Daily activity summary for %s" : "Resumu de is atividades de cada die pro %s",
    "_and %n more _::_and %n more _" : ["and %n more ","e %n in prus"],
    "All activities" : "Totu is atividades",
    "By others" : "Dae àtere",
    "By you" : "Dae te",
    "Hello %s" : "Salude %s",
    "Hello %s," : "Salude %s,",
    "There was some activity at %s" : "Ddoe at àpidu calicuna àtividade a su %s",
    "Mail" : "Posta ",
    "Push" : "Imbia",
    "Activity" : "Atividades",
    "Notifications" : "Notìficas",
    "Send email" : "Imbia messàgiu de posta eletrònica",
    "Today" : "Oe",
    "Yesterday" : "Eris",
    "You need to set up your email address before you can receive notification emails." : "Deves impostare s'indiritzu de posta eletrònica tuo pro retzire is messàgios de notìfica.",
    "Send activity emails" : "Imbia messàgios de atividade",
    "As soon as possible" : "Apena possìbile",
    "Hourly" : "Ogni ora",
    "Daily" : "Ogni die",
    "Weekly" : "Ogni chida",
    "You commented" : "As cummentadu",
    "Message deleted by author" : "Messàgiu cantzelladu dae s'autore",
    "Open {filename}" : "Aberi {filename}",
    "in {path}" : "in {path}",
    "Home" : "Pàgina printzipale",
    "This stream will show events like additions, changes & shares" : "Custu flussu at a mustrare eventos che a agiuntas, càmbios e cumpartziduras",
    "No activity yet" : "Ancora peruna atividade ",
    "Enable RSS feed" : "Ativa su flussu RSS ",
    "RSS feed" : "Ativa su flussu RSS",
    "Unable to load the activity list" : "Non faghet a carrigare sa lista de atividades",
    "Notification" : "Notìfica",
    "Enable notification emails" : "Ativa messàgios de notìfica",
    "Choose for which activities you want to get an email or push notification." : "Sèbera pro cales atividades cheres retzire unu messàgiu o una notìfica automàtica.",
    "Choose for which activities you want to get a push notification." : "Sèbera pro cales atividades cheres retzire una notìfica automàtica.",
    "Send daily activity summary in the morning" : "Imbia unu resumu de is atividades de ogni die a mangianu",
    "Default settings" : "Cunfiguratzione predefinida",
    "No more events to load" : "Perunu eventu de carrigare",
    "Copied!" : "Copiadu!",
    "Not supported!" : "Non suportadu!",
    "Press ⌘-C to copy." : "Incarca ⌘-C pro copiare.",
    "Press Ctrl-C to copy." : "Incarca Ctrl-C pro copiare.",
    "{name} (invisible)" : "{name} (invisìbile)",
    "{name} (restricted)" : "{name} (limitadu)",
    "There are no events for this filter" : "Non ddoe at eventos pro custu filtru"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.10.tar.bz2: nextcloud/apps/activity/l10n/sc.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Flussu de atividade personale de su %s",
    "Your feed URL is invalid" : "S'URL de flussu tuo no est vàlidu",
    "Activity feed" : "Flussu de atividade",
    "Your settings have been updated." : "Cunfiguratzione atualizada.",
    "Settings have been updated." : "Cunfiguratzione atualizada.",
    "Recent activity" : "Atividade reghente",
    "No activities" : "Peruna atividade",
    "Daily activity summary for %s" : "Resumu de is atividades de cada die pro %s",
    "All activities" : "Totu is atividades",
    "By others" : "Dae àtere",
    "By you" : "Dae te",
    "Hello %s" : "Salude %s",
    "Hello %s," : "Salude %s,",
    "There was some activity at %s" : "Ddoe at àpidu calicuna àtividade a su %s",
    "_and %n more _::_and %n more _" : ["and %n more ","e %n in prus"],
    "Mail" : "Posta ",
    "Push" : "Imbia",
    "Activity" : "Atividades",
    "Notifications" : "Notìficas",
    "Send email" : "Imbia messàgiu de posta eletrònica",
    "Today" : "Oe",
    "Yesterday" : "Eris",
    "You need to set up your email address before you can receive notification emails." : "Depes cunfigurare s'indiritzu de posta eletrònica tuo pro retzire is messàgios de notìfica.",
    "Send activity emails" : "Imbia messàgios de atividade",
    "As soon as possible" : "Apena possìbile",
    "Hourly" : "Ogni ora",
    "Daily" : "Ogni die",
    "Weekly" : "Ogni chida",
    "You commented" : "As cummentadu",
    "Message deleted by author" : "Messàgiu cantzelladu dae s'autore",
    "Open {filename}" : "Aberi {filename}",
    "in {path}" : "in {path}",
    "Home" : "Pàgina printzipale",
    "Loading activities" : "Carrighende atividades",
    "This stream will show events like additions, changes & shares" : "Custu flussu at a mustrare eventos che a agiuntas, càmbios e cumpartziduras",
    "No activity yet" : "Ancora peruna atividade ",
    "Loading more activities" : "Carrighende àteras atividades",
    "Activity settings" : "Cunfiguratziones de atividade",
    "Enable RSS feed" : "Ativa su flussu RSS ",
    "RSS feed" : "Ativa su flussu RSS",
    "Unable to load the activity list" : "Non faghet a carrigare sa lista de atividades",
    "Notification" : "Notìfica",
    "Enable notification emails" : "Ativa messàgios de notìfica",
    "Choose for which activities you want to get an email or push notification." : "Sèbera pro cales atividades cheres retzire unu messàgiu o una notìfica automàtica.",
    "Choose for which activities you want to get a push notification." : "Sèbera pro cales atividades cheres retzire una notìfica automàtica.",
    "Send daily activity summary in the morning" : "Imbia unu resumu de is atividades de ogni die a mangianu",
    "Default settings" : "Cunfiguratzione predefinida",
    "Configure the default notification settings for new accounts." : "Cunfigura is paràmetros de notìficas predefinidos pro is contos noos.",
    "No more events to load" : "Perunu eventu de carrigare"
},
"nplurals=2; plural=(n != 1);");
